@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/opt/local/Library/Frameworks/Python.framework/Versions/3.11/bin/python3.11",
 
         # Package versions
-        contourpy_version="1.3.2",
-        meson_version="1.7.2",
-        mesonpy_version="0.17.1",
+        contourpy_version="1.3.3",
+        meson_version="1.8.2",
+        mesonpy_version="0.18.0",
         pybind11_version="2.13.6",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py311-contourpy/work/contourpy-1.3.2/build/lib/contourpy/util",
-        source_dir=r"/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py311-contourpy/work/contourpy-1.3.2/lib/contourpy/util",
+        build_dir=r"/opt/local/var/macports/build/py311-contourpy-7840b687/work/contourpy-1.3.3/build/lib/contourpy/util",
+        source_dir=r"/opt/local/var/macports/build/py311-contourpy-7840b687/work/contourpy-1.3.3/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_python_py-contourpy/py311-contourpy/work/contourpy-1.3.2/build/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/opt/local/var/macports/build/py311-contourpy-7840b687/work/contourpy-1.3.3/build/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
